/*
 * Copyright (C) 2012 Qihoo 360 Technology Co. Ltd, All Rights Reserved.
 */
package net.qihoo.launcher.widget;

import android.content.Context;
import android.graphics.drawable.BitmapDrawable;
import android.util.AttributeSet;
import android.view.View.OnClickListener;
import android.widget.TextView;

/**
 * Class for 1*1 shortcut-like widget, make it looks like a shortcut icon in
 * launcher.
 * 
 * <p>
 * The only thing you should do is overriding {@link #getTopDrawableResID()} ,
 * and giving a top drawable resource ID to this icon.
 * </p>
 * 
 * @version 1.0
 */
@SuppressWarnings("unused")
public abstract class IconWidgetView extends TextView implements OnClickListener, WidgetView {
    protected static final String TAG = "IconWidgetView";

    protected Context mContext;

    protected Context mHostContext;
    
    public IconWidgetView(Context context) {
        this(context, null);
    }

    public IconWidgetView(Context context, AttributeSet attrs) {
        super(context, attrs);
        mContext = context;
        setOnClickListener(this);
    }

    public void init(Context ctx, long widgetID) {
        mHostContext = ctx;
    }

    protected final void setTopDrawable() {
        BitmapDrawable top = (BitmapDrawable) mContext.getResources().getDrawable(getTopDrawableResID());
        setCompoundDrawablesWithIntrinsicBounds(null, top, null, null);
    }

    protected abstract int getTopDrawableResID();

}
