/*
 * Copyright (C) 2012 Qihoo 360 Technology Co. Ltd, All Rights Reserved.
 */
package net.qihoo.launcher.widget;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.Canvas;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;

/**
 * This class defines utilities for this component.
 * 
 * <p>
 * You may needn't care about this class cause it's used by component inner class.
 * </p>
 *
 * @version 1.0
 */
public class Utils {
    public static int dip2px(Context context, float dpValue) {
        final float scale = context.getResources().getDisplayMetrics().density;
        return (int) (dpValue * scale + 0.5f);
    }
    
    public static Bitmap createIconBitmap(Drawable icon, Context context, int width) {
        int iconWidthWithPadding, iconHeightWithPadding;
        iconWidthWithPadding = iconHeightWithPadding = width;

        int textureWidth = iconWidthWithPadding + 2;
        int textureHeight = iconHeightWithPadding + 2;

        int iconWidth, iconHeight;

        iconWidth = iconWidthWithPadding;
        iconHeight = iconHeightWithPadding;

        // Ensure the bitmap has a density.
        BitmapDrawable bitmapDrawable = (BitmapDrawable) icon;
        Bitmap bitmap = bitmapDrawable.getBitmap();
        if (bitmap.getDensity() == Bitmap.DENSITY_NONE) {
            bitmapDrawable.setTargetDensity(context.getResources().getDisplayMetrics());
        }

        int sourceWidth = icon.getIntrinsicWidth();
        int sourceHeight = icon.getIntrinsicHeight();

        if (sourceWidth > 0 && sourceHeight > 0) {
            // There are intrinsic sizes.
            if (iconWidth < sourceWidth || iconHeight < sourceHeight) {
                // It's too big, scale it down.
                final float ratio = (float) sourceWidth / sourceHeight;
                if (sourceWidth > sourceHeight) {
                    iconHeight = (int) (iconWidth / ratio);
                } else if (sourceHeight > sourceWidth) {
                    iconWidth = (int) (iconHeight * ratio);
                }
            } else if (sourceWidth < iconWidth && sourceHeight < iconHeight) {
                // It's small, use the size they gave us.
                float min = Math.min(iconWidth * 1.0f / sourceWidth, iconHeight * 1.0f / sourceHeight);
                iconWidth = (int) (sourceWidth * min);
                iconHeight = (int) (sourceHeight * min);
            }
        }

        if (iconWidth % 2 == 1) {
            iconWidth--;
        }

        iconWidthWithPadding = iconWidth;
        iconHeightWithPadding = iconHeight;

        bitmap = createBitmap(textureWidth, textureHeight, Bitmap.Config.ARGB_8888);
        final Canvas canvas = new Canvas();
        canvas.setBitmap(bitmap);

        final int left = (textureWidth - iconWidthWithPadding) / 2;
        final int top = (textureHeight - iconHeightWithPadding) / 2;
        icon.setBounds(left, top, left + iconWidthWithPadding, top + iconHeightWithPadding);
        icon.draw(canvas);
        return bitmap;
    }

    public static Bitmap createBitmap(int width, int height, Config config) {
        try {
            return Bitmap.createBitmap(width, height, config);
        } catch (OutOfMemoryError e) {
            return Bitmap.createBitmap(width, height, config);
        }
    }
}
