/*
 * Copyright (C) 2012 Qihoo 360 Technology Co. Ltd, All Rights Reserved.
 */
package net.qihoo.launcher.widget;

import android.content.Context;

/**
 * this interface represents the most important class of this component.
 * 
 * <p>
 * any view who want to be a widgetView of launcher, must implements this interface.
 * </p>
 *
 * @version 1.0
 */
public interface WidgetView {

    /**
     * <p>
     * Called when widget is bounded on launcher
     * </p>
     * @param widgetId the unique Id of the widget
     * @param hostContext context of launcher
     */
    void init(Long widgetId, Context hostContext);

    /**
     * <p>
     * Called when widget is added on launcher, maybe added by launcher automatic or by user
     * </p>
     * @param newInstance true if added by user, false if added by launcher
     */
    void onAdded(boolean newInstance);

    /**
     * <p>
     * Called when widget is removed from launcher
     * </p>
     * @param permanent true if removed by user, false if removed by launcher(this may happen when launcher resize all it's layout)
     */
    void onRemoved(boolean permanent);

    /**
     * <p>
     * Called when launcher {@link android.app.Activity#onDestroy}}
     * </p>
     */
    void onDestroy();

    /**
     * <p>
     * Called when launcher {@link android.app.Activity#onPause}}
     * </p>
     */
    void onPause();

    /**
     * <p>
     * Called when launcher {@link android.app.Activity#onResume}}
     * </p>
     */
    void onResume();

    /**
     * <p>
     * Called when launcher receives broadcast {@link android.content.Intent#ACTION_SCREEN_ON}}
     * </p>
     */
    void onScreenOn();

    /**
     * <p>
     * Called when launcher receives broadcast {@link android.content.Intent#ACTION_SCREEN_OFF}}
     * </p>
     */
    void onScreenOff();
}
